@@ -23,6 +23,8 @@ class BufferedCursor:
             self._buffered_values.append(item)
 
         self._buffered_values_iterator = iter(self._buffered_values)
+        self._consumed_ios = cursor.get_consumed_ios()
+        self._timing_information = cursor.get_timing_information()
 
     def __iter__(self):
         """
@@ -35,3 +37,23 @@ class BufferedCursor:
         Iterator function to implement the iterator protocol. Get next value in _buffered_values_iterator.
         """
         return next(self._buffered_values_iterator)
+
+    def get_consumed_ios(self):
+        """
+        Return a dictionary containing the total amount of IO requests for a statement execution. Return None if there
+        were no read IOs for a statement execution.
+
+        :rtype: dict/None
+        :return: The amount of read IO requests for a statement execution.
+        """
+        return self._consumed_ios
+
+    def get_timing_information(self):
+        """
+        Return a dictionary containing the total amount of processing time for a statement execution. Return None if
+        there was no timing information for a statement execution.
+
+        :rtype: dict/None
+        :return: The amount of processing time in milliseconds for a statement execution.
+        """
+        return self._timing_information
